==> log4j-layout-template-json-2.21.1-sources.jar: org/apache/logging/log4j/layout/template/json/resolver/EventResolverStringSubstitutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.layout.template.json.resolver;

import java.util.Objects;

import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.lookup.StrSubstitutor;

/**
 * {@link TemplateResolverStringSubstitutor} specialized for {@link LogEvent}s.
 */
public final class EventResolverStringSubstitutor
        implements TemplateResolverStringSubstitutor<LogEvent> {

    private final StrSubstitutor substitutor;

    public EventResolverStringSubstitutor(final StrSubstitutor substitutor) {
        this.substitutor = Objects.requireNonNull(substitutor, "substitutor");
    }

    @Override
    public StrSubstitutor getInternalSubstitutor() {
        return substitutor;
    }

    @Override
    public boolean isStable() {
        return false;
    }

    @Override
    public String replace(final LogEvent logEvent, final String source) {
        return substitutor.replace(logEvent, source);
    }

}

==> log4j-layout-template-json-2.22.1-sources.jar: org/apache/logging/log4j/layout/template/json/resolver/EventResolverStringSubstitutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.layout.template.json.resolver;

import java.util.Objects;
import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.lookup.StrSubstitutor;

/**
 * {@link TemplateResolverStringSubstitutor} specialized for {@link LogEvent}s.
 */
public final class EventResolverStringSubstitutor implements TemplateResolverStringSubstitutor<LogEvent> {

    private final StrSubstitutor substitutor;

    public EventResolverStringSubstitutor(final StrSubstitutor substitutor) {
        this.substitutor = Objects.requireNonNull(substitutor, "substitutor");
    }

    @Override
    public StrSubstitutor getInternalSubstitutor() {
        return substitutor;
    }

    @Override
    public boolean isStable() {
        return false;
    }

    @Override
    public String replace(final LogEvent logEvent, final String source) {
        return substitutor.replace(logEvent, source);
    }
}
